==> qtjambi-virtualkeyboard-jre8-5.15.3-sources.jar: io/qt/keyboard/QVirtualKeyboardExtensionPlugin.java <==
package io.qt.keyboard;


/**
 * <p>Extension plugin for the Qt Virtual Keyboard</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qvirtualkeyboardextensionplugin.html">QVirtualKeyboardExtensionPlugin</a></p>
 */
public class QVirtualKeyboardExtensionPlugin extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QVirtualKeyboardExtensionPlugin.class);
    
    
    public QVirtualKeyboardExtensionPlugin(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QVirtualKeyboardExtensionPlugin instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvirtualkeyboardextensionplugin.html#registerTypes">QVirtualKeyboardExtensionPlugin::registerTypes(const char*)const</a></p>
     */
    @io.qt.QtUninvokable
    public void registerTypes(java.lang.String uri){
        registerTypes_native_const_char_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), uri);
    }
    
    @io.qt.QtUninvokable
    private native void registerTypes_native_const_char_ptr_constfct(long __this__nativeId, java.lang.String uri);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QVirtualKeyboardExtensionPlugin(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QVirtualKeyboardExtensionPlugin(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QVirtualKeyboardExtensionPlugin instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-virtualkeyboard-jre8-6.2-sources.jar: io/qt/keyboard/QVirtualKeyboardExtensionPlugin.java <==
package io.qt.keyboard;


/**
 * <p>Extension plugin for the Qt Virtual Keyboard</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qvirtualkeyboardextensionplugin.html">QVirtualKeyboardExtensionPlugin</a></p>
 */
public class QVirtualKeyboardExtensionPlugin extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QVirtualKeyboardExtensionPlugin.class);
    
    
    public QVirtualKeyboardExtensionPlugin(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QVirtualKeyboardExtensionPlugin instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvirtualkeyboardextensionplugin.html#registerTypes">QVirtualKeyboardExtensionPlugin::registerTypes(const char*)const</a></p>
     */
    @io.qt.QtUninvokable
    public void registerTypes(java.lang.String uri){
        registerTypes_native_const_char_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), uri);
    }
    
    @io.qt.QtUninvokable
    private native void registerTypes_native_const_char_ptr_constfct(long __this__nativeId, java.lang.String uri);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QVirtualKeyboardExtensionPlugin(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QVirtualKeyboardExtensionPlugin(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QVirtualKeyboardExtensionPlugin instance, QDeclarativeConstructor constructor);
    
}
